#!/bin/bash
# Name: gkrellm
# Author:  Bill Wilson <billw--at--gkrellm.net>
# Homepage: http://gkrellm.net
# source: http://members.dslextreme.com/users/billw/gkrellm/gkrellm-2.3.3.tar.bz2
#       : http://oss.pugsplace.net/gkrellm-countdown-0.1.2.tar.gz
#
# maintainer: BandiPat <penguin0601@earthlink.net>
# Platform: Zenwalk

#------------------Set Some Variables

soft="gkrellm"
softversion="2.3.3"
arch="i486"
cpu="i686"
packageversion="64.1"
#
# where could you get the source
#
srcurl="http://members.dslextreme.com/users/billw/gkrellm/"$soft"-"$softversion".tar.bz2"
#
#  lonesome hook:  To include all build info into the final build.txt file at end
#
(

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest/install

#-----------------Make the slack-desc files

cat << EODESC > $dest/install/slack-desc
       |-----handy-ruler-------------------------------------------------------|
gkrellm: gkrellm (GNU Krell Monitors)
gkrellm:
gkrellm: GKrellM charts SMP CPU, load, Disk, and all active net interfaces
gkrellm: automatically. An on/off button and online timer for the PPP interface
gkrellm: is provided. Monitors for memory and swap usage, file system, internet
gkrellm: connections, APM laptop battery, mbox style mailboxes, and cpu temps.
gkrellm: Also includes an uptime monitor, hostname label, and clock/calendar.
gkrellm:
gkrellm: Bill Wilson is the author of GKrellM.
gkrellm:
gkrellm:
EODESC

#------------------Set correct permissions

cd $src

# Increase the default width slightly, and don't use the text
# shadow effect by default (this seems better with Pango font
# rendering):
zcat $buildir/gkrellm.theme.defaults.diff.gz | patch -p1 --verbose || exit 1
chown -R root:root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 664 -exec chmod 644 {} \;
make \
  INSTALLROOT=/usr \
  INSTALLDIR=/usr/bin \
  INCLUDEDIR=/usr/include \
  MANDIR=/usr/man/man1 \
  LOCALEDIR=/usr/share/locale \
  PKGCONFIGDIR=/usr/lib/pkgconfig

make install

# Install to the $dest dir:

make install \
  INSTALLROOT=$dest/usr \
  INSTALLDIR=$dest/usr/bin \
  INCLUDEDIR=$dest/usr/include \
  MANDIR=$dest/usr/man/man1 \
  LOCALEDIR=$dest/usr/share/locale \
  PKGCONFIGDIR=$dest/usr/lib/pkgconfig
mkdir -p $dest/usr/lib/gkrellm2/plugins
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  Changelog *.html COPYING COPYRIGHT CREDITS INSTALL README \
  $dest/usr/doc/$soft-$softversion
gzip -9 $dest/usr/man/man?/*.?

# Add optional plugin(s):
# The countdown plugin is needed to track X-Day.  ;-)

countdown=0.1.2
cd $buildir
rm -rf gkrellm-countdown
tar xzf $buildir/gkrellm-countdown-$countdown.tar.gz
cd gkrellm-countdown
chown -R root:root .
make
cp gkrellm-countdown.so $dest/usr/lib/gkrellm2/plugins
mkdir -p $dest/usr/doc/gkrellm-countdown-$countdown
cp -a \
  COPYING ChangeLog README \
  $dest/usr/doc/gkrellm-countdown-$countdown

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

mkdir -p $dest/usr/share/applications

cat << EOF > $dest/usr/share/applications/gkrellm.desktop
[Desktop Entry]
Encoding=UTF-8
Exec=gkrellm
Icon=gnome-monitor
Name=GKrellM
Terminal=false
Type=Application
Categories=Application;Utility;
EOF

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion
cp $buildir/*.diff.gz $dest/usr/src/$soft-$softversion

#
# real packaging work: 
#
chown -R root.root $dest/$prefix

echo "--- packaging -----"


#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.tlz
(
 cd $buildir
 echo "---Building md5---"
 md5sum $package.tlz > $package.md5
 echo "---Building dep file---"
 depfinder -f $package.tlz >$package.dep
 echo "---generating the .src file & build text---"
#
# produce the file src
#
echo http://zenwalk.pinguix.com/user-accounts/BandiPat/source/build-files/build-gkrellm.sh > $package.src
echo $srcurl >> $package.src
echo "---Creating the build text---"
)

#
# the other end of the lonesome hook: 
#
) 2>&1 | tee "$soft-$softversion-build.txt"

